# Copyright 2016 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Configuration provider for gpgservice."""

import ConfigParser
from contextlib import contextmanager
import os
import os.path

import gpgservice


def _read_config():
    root = os.path.abspath(
        os.path.join(os.path.dirname(gpgservice.__file__), '..'))
    config = ConfigParser.SafeConfigParser(dict(ROOT=root))
    default_path = os.path.join(root, 'service.conf')
    config.read(os.environ.get('GPGSERVICE_CONFIG_PATH', default_path))
    return config


config = _read_config()


@contextmanager
def set_config_value(section, option,  value):
    """Set a config value to something new, for the duration of a test.

    :param key: The section name, for example 'gpghandler'
    :param option: The option name, for example 'upload_keys'
    :param value: The value you want to set, for example 'True'

    """

    old_value = config.get(section, option)
    if not isinstance(value, basestring):
        value = repr(value)

    config.set(section, option, value)
    try:
        yield
    finally:
        config.set(section, option, old_value)
