# Copyright 2009-2016 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import os
import shutil

from txfixtures.tachandler import TacTestFixture

from gpgservice.config import config


__metaclass__ = type
KEYS_DIR = os.path.join(os.path.dirname(__file__), 'tests/keys')


class KeyServerTac(TacTestFixture):
    """A test key server for use by functional tests."""

    def setUp(self):
        """Check the environ for the twistd path."""
        twistd_path = os.environ.get('TWISTD_PATH')
        super(KeyServerTac, self).setUp(twistd_script=twistd_path)

    def setUpRoot(self):
        """Recreate root directory and copy needed keys"""
        if os.path.isdir(self.root):
            shutil.rmtree(self.root)
        shutil.copytree(KEYS_DIR, self.root)

    @property
    def daemon_port(self):
        return config.getint('gpghandler', 'port')

    @property
    def root(self):
        return config.get('testkeyserver', 'working_dir')

    @property
    def tacfile(self):
        return os.path.abspath(
            os.path.join(os.path.dirname(__file__), 'testkeyserver.tac'))

    @property
    def pidfile(self):
        return os.path.join(self.root, 'testkeyserver.pid')

    @property
    def logfile(self):
        return os.path.join(self.root, 'testkeyserver.log')

    @property
    def url(self):
        """The URL that the web server will be running on."""
        return 'http://%s:%d' % (
            config.get('gpghandler', 'host'),
            config.getint('gpghandler', 'port'))
