# -*- coding: utf-8 -*-
# Copyright 2016 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).
import os.path
import tempfile

from fixtures import EnvironmentVariable
from testtools import TestCase
from testtools.matchers import (
    Contains,
    SamePath,
    )

import gpgservice
from gpgservice.config import _read_config


class ReadConfigTestCase(TestCase):

    def test_config_root_set_correctly(self):
        config = _read_config()
        expected_root = os.path.join(
            os.path.dirname(gpgservice.__file__), '..')
        self.assertThat(config.defaults(), Contains('root'))
        self.assertThat(config.defaults()['root'], SamePath(expected_root))

    def test_can_override_config_file_path(self):
        with tempfile.NamedTemporaryFile(mode='w') as conffile:
            conffile.write(
                "[test]\n"
                "some_option = some_value"
            )
            conffile.flush()
            self.useFixture(
                EnvironmentVariable('GPGSERVICE_CONFIG_PATH', conffile.name))
            config = _read_config()
            # Sadly ConfigParser doesn't store which files were read, so check
            # that we read the correct file by matching the contents above:
            self.assertThat(config.sections(), Contains('test'))
            self.assertEqual('some_value', config.get('test', 'some_option'))


def test_suite():
    from unittest import TestLoader
    return TestLoader().loadTestsFromName(__name__)
